#
# spec file for package libpreludedb
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitearch3: %global python_sitearch3 %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%define sover 7
%define sover_cpp 2
Name:           libpreludedb
Version:        5.2.0
Release:        2.12
Summary:        Framework to easy access to the Prelude database
# Prelude is GPL-2.0+
# libmissing is LGPL-2.1+
# libmissing/test is GPL-3.0+
License:        GPL-2.0-or-later AND LGPL-2.1-only AND GPL-3.0-or-later
Group:          Productivity/Networking/Security
URL:            https://www.prelude-siem.org
Source0:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz
Source1:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz.sig
Source2:        https://www.prelude-siem.org/attachments/download/233/RPM-GPG-KEY-Prelude-IDS#/%{name}.keyring
# Fix undefined non weak symbol
Patch0:         libpreludedb-undefined_non_weak_symbol.patch
Patch1:         libpreludedb-fix_gtkdoc_1.32.patch
Patch3:         libpreludedb-force_preludedb_admin_with_py3.patch
Patch4:         libpreludedb-update_m4_postgresql.patch
BuildRequires:  gcc-c++
BuildRequires:  gtk-doc
BuildRequires:  libprelude-devel >= 5.2.0
BuildRequires:  mysql-devel
BuildRequires:  pkgconfig
BuildRequires:  postgresql-devel
BuildRequires:  python3-devel
BuildRequires:  sqlite-devel >= 3.0.0
Requires:       libprelude-tools >= 5.2.0
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150200
BuildRequires:  postgresql-server-devel
%endif

%description
The PreludeDB Library provides an abstraction layer upon the type and the
format of the database used to store IDMEF alerts. It allows developers
to use the Prelude IDMEF database easily and efficiently without
worrying about SQL, and to access the database independently of the
type/format of the database.

%package -n %{name}%{sover}
Summary:        Prelude Libraries
Group:          System/Libraries

%description -n %{name}%{sover}
The PreludeDB Library provides an abstraction layer upon the type and the
format of the database used to store IDMEF alerts. It allows developers
to use the Prelude IDMEF database easily and efficiently without
worrying about SQL, and to access the database independently of the
type/format of the database.

%package -n %{name}cpp%{sover_cpp}
Summary:        Prelude Libraries
Group:          System/Libraries

%description -n %{name}cpp%{sover_cpp}
The PreludeDB Library provides an abstraction layer upon the type and the
format of the database used to store IDMEF alerts. It allows developers
to use the Prelude IDMEF database easily and efficiently without
worrying about SQL, and to access the database independently of the
type/format of the database.

%package devel
Summary:        Development files for libpreludedb
Group:          Development/Libraries/C and C++
Requires:       automake
Requires:       libprelude-devel >= 5.2.0
Requires:       libpreludedb%{sover} = %{version}
Requires:       libpreludedbcpp%{sover_cpp} = %{version}
Requires:       mysql-devel
Requires:       postgresql-devel
Requires:       sqlite-devel

%description devel
The PreludeDB Library provides an abstraction layer upon the type
and the format of the database used to store IDMEF alerts. It
allows developers to use the Prelude IDMEF database easily and
efficiently without worrying about SQL, and to access the
database independently of the type/format of the database.

%package devel-bindings
Summary:        Development files for libpreludedb
Group:          Development/Libraries/C and C++
Requires:       libpreludedb-devel = %{version}
Requires:       python3-devel
Requires:       swig

%description devel-bindings
The PreludeDB Library provides an abstraction layer upon the type
and the format of the database used to store IDMEF alerts. It
allows developers to use the Prelude IDMEF database easily and
efficiently without worrying about SQL, and to access the
database independently of the type/format of the database.

%package -n preludedb-tools
Summary:        Tools of libpreludedb
Group:          Productivity/Networking/Security

%description -n preludedb-tools
The PreludeDB Library provides an abstraction layer upon the type
and the format of the database used to store IDMEF alerts. It
allows developers to use the Prelude IDMEF database easily and
efficiently without worrying about SQL, and to access the
database independently of the type/format of the database.

%package plugins
Summary:        Plugin to use prelude with a classic schema
Group:          Productivity/Networking/Security

%description plugins
This plugin allows prelude to store alerts into a classic
schema in database.

%package mysql
Summary:        Plugin to use prelude with a mysql database
Group:          Productivity/Networking/Security
Requires:       libpreludedb-plugins = %{version}
Requires:       mysql
Requires:       mysql-server

%description mysql
This plugin allows prelude to store alerts into a mysql database.

%package pgsql
Summary:        Plugin to use prelude with a pgsql database
Group:          Productivity/Networking/Security
Requires:       libpreludedb-plugins = %{version}
Requires:       postgresql-server

%description pgsql
This plugin allows prelude to store alerts into a pgsql database.

%package sqlite
Summary:        Plugin to use prelude with a sqlite database
Group:          Productivity/Networking/Security
Requires:       libpreludedb-plugins = %{version}
Requires:       sqlite

%description sqlite
This plugin allows prelude to store alerts into a sqlite database.

%package -n python3-%{name}
Summary:        Python 3 bindings for libpreludedb
Group:          Development/Languages/Python

%description -n python3-%{name}
Python 3 bindings for libpreludedb generated by SWIG.

%package doc
Summary:        Libprelude documentation
Group:          Documentation/HTML

%description doc
Libprelude documentation files.

%prep
%setup -q
%patch0
%patch1
%patch3
%patch4

%build
%configure --with-html-dir=%{_defaultdocdir}/%{name}-%{version}/html \
           --without-python2 \
           --disable-static \
           --enable-gtk-doc

sed -i.rpath -e 's|LD_RUN_PATH=""||' bindings/Makefile
sed -i.rpath -e 's|^sys_lib_dlsearch_path_spec="/lib %{_prefix}/lib|sys_lib_dlsearch_path_spec="/%{_lib} %{_libdir}|' libtool

%make_build

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/libpreludedb%{sover}/swig/python
cp bindings/libpreludedbcpp.i %{buildroot}%{_datadir}/libpreludedb%{sover}/swig/
cp bindings/python/libpreludedbcpp-python.i %{buildroot}%{_datadir}/libpreludedb%{sover}/swig/python
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'

%post -n libpreludedb%{sover} -p /sbin/ldconfig
%post -n libpreludedbcpp%{sover_cpp} -p /sbin/ldconfig
%postun -n libpreludedb%{sover} -p /sbin/ldconfig
%postun -n libpreludedbcpp%{sover_cpp} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%{_libdir}/libpreludedb.so.%{sover}*

%files -n %{name}cpp%{sover_cpp}
%license COPYING
%{_libdir}/libpreludedbcpp.so.%{sover_cpp}*

%files -n preludedb-tools
%license COPYING
%{_mandir}/man1/preludedb-admin.1%{?ext_man}
%{_bindir}/preludedb-admin

%files plugins
%license COPYING
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_libdir}/%{name}/plugins/formats/

%files devel
%license COPYING
%{_bindir}/libpreludedb-config
%{_includedir}/libpreludedb
%{_libdir}/libpreludedb.so
%{_libdir}/libpreludedbcpp.so
%{_datadir}/aclocal/libpreludedb.m4
%{_mandir}/man1/libpreludedb-config.1%{?ext_man}

%files devel-bindings
%license COPYING
%dir %{_datadir}/libpreludedb%{sover}/
%dir %{_datadir}/libpreludedb%{sover}/swig/
%{_datadir}/libpreludedb%{sover}/swig/libpreludedbcpp.i
%dir %{_datadir}/libpreludedb%{sover}/swig/python/
%{_datadir}/libpreludedb%{sover}/swig/python/libpreludedbcpp-python.i

%files -n python3-%{name}
%license COPYING
%{python_sitearch3}/*

%files mysql
%license COPYING
%defattr(0755,root,root)
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/sql
%{_libdir}/%{name}/plugins/sql/mysql.so
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/classic
%attr(0644,root,root) %{_datadir}/%{name}/classic/mysql*.sql
%attr(0755,root,root) %{_datadir}/%{name}/classic/*.sh

%files sqlite
%license COPYING
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/sql
%{_libdir}/%{name}/plugins/sql/sqlite3.so
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/classic
%{_datadir}/%{name}/classic/sqlite*

%files pgsql
%license COPYING
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%dir %{_libdir}/%{name}/plugins/sql
%{_libdir}/%{name}/plugins/sql/pgsql.so
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/classic
%{_datadir}/%{name}/classic/pgsql*

%files doc
%license COPYING LICENSE.README
%doc %{_docdir}/%{name}-%{version}
%doc ChangeLog README NEWS HACKING.README

%changelog
* Thu Jul  1 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove python-devel Requires on devel-bindings package
* Sun Oct 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- libpreludedb 5.2.0:
  * build system fixes
  * Python 3.7/3.8 support
  * Update to SWIG 4.0.1
  * Escaping fixes with LIKE operator
- drop upstreamed patches:
  * libpreludedb-fix_py38.patch
- add upstream signing key and verify source signature
* Sun Mar 15 2020 Max Lin <mlin@suse.com>
- BuildRequires postgresql-server-devel on Leap >= 15.2 as well
* Fri Oct 25 2019 thomas.andrejak@gmail.com
  Bump version 5.1.0
  - Update internal dependencies (SWIG, ...)
  - Rewrite preludedb-admin in python, multiprocess compatible
  - Improve bindings
  - Add functions (AVG, SUM, ...)
  - Multiprocess compatibility
  - Add missing operators
- Add patchs:
  - libpreludedb-force_preludedb_admin_with_py3.patch
  - Force using Python 3 for preludedb-admin
  - libpreludedb-fix_gtkdoc_1.32.patch
  - Support of recents gtkdoc versions
  - libpreludedb-fix_py38.patch
  - Add support for Python3.8
  - libpreludedb-update_m4_postgresql.patch
  - Compatibility with PostgreSQL >= 10
- Remove patch:
  - libpreludedb-manpages.patch
  - Fixed upstream
- Remove Python 2 support
  - Python 2 will be removed step by step in all Linux distributions
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing build dependency for Tumbleweed.
* Fri Mar  1 2019 thomas.andrejak@gmail.com
  Bump version 5.0.0
- Remove patchs included in new version
  - libpreludedb-fix-gtk-doc.patch
* Wed Oct  4 2017 thomas.andrejak@gmail.com
- Bump to libpreludedb 4.0.0
- Add patchs:
  - libpreludedb-fix-gtk-doc.patch: gtk-doc removed gtkdoc-tmpl so gtk-doc.make
    and gtk-doc.m4 need to be updated
  - libpreludedb-manpages.patch: Error in manpage description
  - libpreludedb-undefined_non_weak_symbol.patch: Fix undefined non weak symbol
- Remove libgcrypt-devel from BuildRequires since upstream totally move to
  gnutls
- Rename python-preludedb to python2-preludedb
* Thu Mar 30 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use
* Sun Nov 27 2016 thomas.andrejak@gmail.com
- Update to 3.1.0 (Prelude 3.1.0 released on 14 Sept 2016)
- Remove unnecessary patches (libpreludedb-python-swig.patch)
- Use a lib directory with soname
- Spec-Cleaner
* Sat Oct  1 2016 thomas.andrejak@gmail.com
- Fix which version of postgresql to use
    Force using postgresql94 as expected in Leap42.2
    Next time, update to do like
    packages in server:database:postgresql
* Thu Sep 15 2016 thomas.andrejak@gmail.com
- Update licence from GPL-2.0+ to GPL-3.0+ to include libmissing
* Tue Jun 28 2016 jengelh@inai.de
- Drop manual library and python requires (autodetected).
  Ensure shared library packaging guideline is followed
  (no extra files in shlib subpackages).
  Fixup RPM groups. Devel package failed to pull in the cpp wrapper.
* Tue May  3 2016 thomas.andrejak@gmail.com
  Initial import
  Generate the lib, the plugins and bindings :
  * Bindings :
  * Python
  * Python 3
  * Plugins :
  * MySQL
  * PostgreSQL
  * SQLite
  Include libpreludedb-python-swig.patch to compile
  with python 3.
